pub trait Field<'a, DB: Backend> {
// Required methods
fn field_name(&self) -> Option<&str>;
fn value(&self) -> Option<DB::RawValue<'_>>;
// Provided method
fn is_null(&self) -> bool { ... }
}Expand description
Represents a single field in a database row.
This trait allows retrieving information on the name of the column and on the value of the field.
Required Methods
Sourcefn field_name(&self) -> Option<&str>
fn field_name(&self) -> Option<&str>
The name of the current field
Returns None if it’s an unnamed field
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".