IntoOwnedRow

Trait IntoOwnedRow 

pub trait IntoOwnedRow<'a, DB: Backend>: Row<'a, DB> {
    type OwnedRow: Row<'a, DB> + Send + 'static;
    type Cache: Default + 'static;

    // Required method
    fn into_owned(self, cache: &mut Self::Cache) -> Self::OwnedRow;
}
Available on crate feature i-implement-a-third-party-backend-and-opt-into-breaking-changes only.
A row that can be turned into an owned version

Required Associated Types

type OwnedRow: Row<'a, DB> + Send + 'static

The owned version of the row

type Cache: Default + 'static

A store for cached information between rows for faster access

Required Methods

fn into_owned(self, cache: &mut Self::Cache) -> Self::OwnedRow

Turn the row into its owned version

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors